==> ejc-probid-impl-3.0.0-20220715.082857-6-sources.jar: com/ejianc/business/bid/bean/RegisDataEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 报名资料
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probid_bid_regis_data")
public class RegisDataEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="project_id")
    private Long projectId; // 招标项目Id
    @TableField(value="project_name")
    private String projectName; // 招标项目名称（带入）
    @TableField(value="project_code")
    private String projectCode; // 招标项目编号
    @TableField(value="construction_unit")
    private String constructionUnit; // 建设单位
    @TableField(value="registration_deadline")
    private Date registrationDeadline; // 报名截止日期
    @TableField(value="opening_date")
    private Date openingDate; // 开标日期
    @TableField(value="bid_unit_id")
    private Long bidUnitId; // 投标单位
    @TableField(value="bid_unit_name")
    private String bidUnitName; // 投标单位 名称
    @TableField(value="bid_unit_code")
    private String bidUnitCode; // 投标单位 编码
    @TableField(value="data_buy_type")
    private String dataBuyType; // 资料购买类型 0:购买资格预审文件、1:购买招标文件、2:其他
    @TableField(value="transact_information_id")
    private String transactInformationId; // 办理资料
    @TableField(value="transact_information_name")
    private String transactInformationName; // 办理资料 名称
    @TableField(value="the_date")
    private Date theDate; // 办理日期
    @TableField(value="employee_code")
    private String employeeCode; // 经办人编码
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="commit_data")
    private Date commitData; // 提交日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名字
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getConstructionUnit() {
        return constructionUnit;
    }

    public void setConstructionUnit(String constructionUnit) {
        this.constructionUnit = constructionUnit;
    }
    public Date getRegistrationDeadline() {
        return registrationDeadline;
    }

    public void setRegistrationDeadline(Date registrationDeadline) {
        this.registrationDeadline = registrationDeadline;
    }
    public Date getOpeningDate() {
        return openingDate;
    }

    public void setOpeningDate(Date openingDate) {
        this.openingDate = openingDate;
    }
    public Long getBidUnitId() {
        return bidUnitId;
    }

    public void setBidUnitId(Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    public String getBidUnitName() {
        return bidUnitName;
    }

    public void setBidUnitName(String bidUnitName) {
        this.bidUnitName = bidUnitName;
    }
    public String getBidUnitCode() {
        return bidUnitCode;
    }

    public void setBidUnitCode(String bidUnitCode) {
        this.bidUnitCode = bidUnitCode;
    }
    public String getDataBuyType() {
        return dataBuyType;
    }

    public void setDataBuyType(String dataBuyType) {
        this.dataBuyType = dataBuyType;
    }
    public String getTransactInformationId() {
        return transactInformationId;
    }

    public void setTransactInformationId(String transactInformationId) {
        this.transactInformationId = transactInformationId;
    }
    public String getTransactInformationName() {
        return transactInformationName;
    }

    public void setTransactInformationName(String transactInformationName) {
        this.transactInformationName = transactInformationName;
    }
    public Date getTheDate() {
        return theDate;
    }

    public void setTheDate(Date theDate) {
        this.theDate = theDate;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public Date getCommitData() {
        return commitData;
    }

    public void setCommitData(Date commitData) {
        this.commitData = commitData;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-probid-impl-3.0.0-20250924.090457-93-sources.jar: com/ejianc/business/bid/bean/RegisDataEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 报名资料
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probid_bid_regis_data")
public class RegisDataEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="project_id")
    private Long projectId; // 招标项目Id
    @TableField(value="project_name")
    private String projectName; // 招标项目名称（带入）
    @TableField(value="project_code")
    private String projectCode; // 招标项目编号
    @TableField(value="construction_unit")
    private String constructionUnit; // 建设单位
    @TableField(value="registration_deadline")
    private Date registrationDeadline; // 报名截止日期
    @TableField(value="opening_date")
    private Date openingDate; // 开标日期
    @TableField(value="bid_unit_id")
    private Long bidUnitId; // 投标单位
    @TableField(value="bid_unit_name")
    private String bidUnitName; // 投标单位 名称
    @TableField(value="bid_unit_code")
    private String bidUnitCode; // 投标单位 编码
    @TableField(value="data_buy_type")
    private String dataBuyType; // 资料购买类型 0:购买资格预审文件、1:购买招标文件、2:其他
    @TableField(value="transact_information_id")
    private String transactInformationId; // 办理资料
    @TableField(value="transact_information_name")
    private String transactInformationName; // 办理资料 名称
    @TableField(value="the_date")
    private Date theDate; // 办理日期
    @TableField(value="employee_code")
    private String employeeCode; // 经办人编码
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="commit_data")
    private Date commitData; // 提交日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态 ：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名字
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value = "data_buy_type_str")
    private String dataBuyTypeStr; // 资料购买类型 0:购买资格预审文件、1:购买招标文件、2:其他


    public String getDataBuyTypeStr() {
        return dataBuyTypeStr;
    }

    public void setDataBuyTypeStr(String dataBuyTypeStr) {
        this.dataBuyTypeStr = dataBuyTypeStr;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getConstructionUnit() {
        return constructionUnit;
    }

    public void setConstructionUnit(String constructionUnit) {
        this.constructionUnit = constructionUnit;
    }
    public Date getRegistrationDeadline() {
        return registrationDeadline;
    }

    public void setRegistrationDeadline(Date registrationDeadline) {
        this.registrationDeadline = registrationDeadline;
    }
    public Date getOpeningDate() {
        return openingDate;
    }

    public void setOpeningDate(Date openingDate) {
        this.openingDate = openingDate;
    }
    public Long getBidUnitId() {
        return bidUnitId;
    }

    public void setBidUnitId(Long bidUnitId) {
        this.bidUnitId = bidUnitId;
    }
    public String getBidUnitName() {
        return bidUnitName;
    }

    public void setBidUnitName(String bidUnitName) {
        this.bidUnitName = bidUnitName;
    }
    public String getBidUnitCode() {
        return bidUnitCode;
    }

    public void setBidUnitCode(String bidUnitCode) {
        this.bidUnitCode = bidUnitCode;
    }
    public String getDataBuyType() {
        return dataBuyType;
    }

    public void setDataBuyType(String dataBuyType) {
        this.dataBuyType = dataBuyType;
    }
    public String getTransactInformationId() {
        return transactInformationId;
    }

    public void setTransactInformationId(String transactInformationId) {
        this.transactInformationId = transactInformationId;
    }
    public String getTransactInformationName() {
        return transactInformationName;
    }

    public void setTransactInformationName(String transactInformationName) {
        this.transactInformationName = transactInformationName;
    }
    public Date getTheDate() {
        return theDate;
    }

    public void setTheDate(Date theDate) {
        this.theDate = theDate;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public Date getCommitData() {
        return commitData;
    }

    public void setCommitData(Date commitData) {
        this.commitData = commitData;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
